@@ -22,6 +22,7 @@ class GitCommitHandler(IPythonHandler):
         g = Github(os.getenv("GIT_TOKEN"))
         branch = os.getenv("GIT_BRANCH_NAME")
         repo_name = os.getenv("GIT_REPO")
+        print("Sending git commit")
         if branch:
             repo_branch = repo_name + "/" + branch
             repo = g.get_repo(repo_branch)
@@ -37,6 +38,7 @@ class GitCommitHandler(IPythonHandler):
         self.process_commit(g, contents, repo, filename, msg, branch)
 
     def process_commit(self, g, contents, repo, new_file, msg, branch):
+        print("Processing git commit")
         while contents:
             file_content = contents.pop(0)
             if file_content.type == "dir":
